@@ -5,7 +5,7 @@
  *
  *  /MathJax/unpacked/config/TeX-AMS_HTML.js
  *  
- *  Copyright (c) 2010-2014 The MathJax Consortium
+ *  Copyright (c) 2010-2015 The MathJax Consortium
  *
  *  Part of the MathJax library.
  *  See http://www.mathjax.org for details.
@@ -17,8 +17,8 @@
  */
 
 MathJax.Hub.Config({
-  extensions: ["tex2jax.js","MathEvents.js","MathZoom.js","MathMenu.js","toMathML.js","TeX/noErrors.js","TeX/noUndefined.js","TeX/AMSmath.js","TeX/AMSsymbols.js"],
-  jax: ["input/TeX","output/HTML-CSS"]
+  extensions: ["tex2jax.js","MathEvents.js","MathZoom.js","MathMenu.js","toMathML.js","TeX/noErrors.js","TeX/noUndefined.js","TeX/AMSmath.js","TeX/AMSsymbols.js","fast-preview.js","AssistiveMML.js"],
+  jax: ["input/TeX","output/HTML-CSS","output/PreviewHTML"]
 });
 
 MathJax.Ajax.loadComplete("[MathJax]/config/TeX-AMS_HTML.js");
