@@ -240,12 +240,18 @@ MathJax.Hub.Config({
     ALT: false,          //    require Alt or Option?
     CMD: false,          //    require CMD?
     Shift: false,        //    require Shift?
+    discoverable: false, //  make math menu discoverable on hover?
     zscale: "200%",      //  the scaling factor for MathZoom
+    renderer: null,      //  set when Jax are loaded
     font: "Auto",        //  what font HTML-CSS should use
     context: "MathJax",  //  or "Browser" for pass-through to browser menu
+    locale: null,        //  the language to use for messages
     mpContext: false,    //  true means pass menu events to MathPlayer in IE
     mpMouse: false,      //  true means pass mouse events to MathPlayer in IE
     texHints: true,      //  include class names for TeXAtom elements
+    FastPreview: null,   //  use PreviewHTML output as preview?
+    assistiveMML: null,  //  include hidden MathML for screen readers?
+    inTabOrder: true,    //  set to true if math elements should be included in the tabindex
     semantics: false     //  add semantics tag with original form in MathML output
   },
   
