@@ -30,7 +30,7 @@ MathJax.ElementJax.mml = MathJax.ElementJax({
   mimeType: "jax/mml"
 },{
   id: "mml",
-  version: "2.5.0",
+  version: "2.6.0",
   directory: MathJax.ElementJax.directory + "/mml",
   extensionDir: MathJax.ElementJax.extensionDir + "/mml",
   optableDir: MathJax.ElementJax.directory + "/mml/optable"
@@ -264,6 +264,7 @@ MathJax.ElementJax.mml.Augment({
     noInheritAttribute: {
       texClass: true
     },
+    getRemoved: {},
     linebreakContainer: false,
     
     Init: function () {
@@ -312,6 +313,7 @@ MathJax.ElementJax.mml.Augment({
       var obj = this.inherit; var root = obj;
       while (obj) {
         var value = obj[name]; if (value == null && obj.attr) {value = obj.attr[name]}
+        if (obj.removedStyles && obj.getRemoved[name] && value == null) value = obj.removedStyles[obj.getRemoved[name]];
         if (value != null && obj.noInheritAttribute && !obj.noInheritAttribute[name]) {
           var noInherit = obj.noInherit[this.type];
           if (!(noInherit && noInherit[name])) {return value}
@@ -399,6 +401,13 @@ MathJax.ElementJax.mml.Augment({
     isEmbellished: function () {return false},
     Core: function () {return this},
     CoreMO: function () {return this},
+    childIndex: function(child) {
+      if (child == null) return;
+      for (var i = 0, m = this.data.length; i < m; i++) if (child === this.data[i]) return i;
+    },
+    CoreIndex: function () {
+      return (this.inferRow ? this.data[0]||this : this).childIndex(this.Core());
+    },
     hasNewline: function () {
       if (this.isEmbellished()) {return this.CoreMO().hasNewline()}
       if (this.isToken || this.linebreakContainer) {return false}
@@ -409,7 +418,7 @@ MathJax.ElementJax.mml.Augment({
     },
     array: function () {if (this.inferred) {return this.data} else {return [this]}},
     toString: function () {return this.type+"("+this.data.join(",")+")"},
-    getAnnotation: function () { return null; }
+    getAnnotation: function () {return null}
   },{
     childrenSpacelike: function () {
       for (var i = 0, m = this.data.length; i < m; i++)
@@ -419,7 +428,7 @@ MathJax.ElementJax.mml.Augment({
     childEmbellished: function () {
       return (this.data[0] && this.data[0].isEmbellished());
     },
-    childCore: function () {return this.data[0]},
+    childCore: function () {return (this.inferRow && this.data[0] ? this.data[0].Core() : this.data[0])},
     childCoreMO: function () {return (this.data[0] ? this.data[0].CoreMO() : null)},
     setChildTeXclass: function (prev) {
       if (this.data[0]) {
@@ -684,6 +693,17 @@ MathJax.ElementJax.mml.Augment({
                     this.texClass === MML.TEXCLASS.CLOSE ||
                     this.texClass === MML.TEXCLASS.PUNCT)) {
         prev.texClass = this.prevClass = MML.TEXCLASS.ORD;
+      } else if (this.texClass === MML.TEXCLASS.BIN) {
+        //
+        // Check if node is the last one in its container since the rule
+        // above only takes effect if there is a node that follows.
+        //
+        var child = this, parent = this.parent;
+        while (parent && parent.parent && parent.isEmbellished() &&
+              (parent.data.length === 1 ||
+              (parent.type !== "mrow" && parent.Core() === child))) // handles msubsup and munderover
+                 {child = parent; parent = parent.parent}
+        if (parent.data[parent.data.length-1] === child) this.texClass = MML.TEXCLASS.ORD;
       }
       return this;
     }
@@ -904,9 +924,7 @@ MathJax.ElementJax.mml.Augment({
       if (level == null) {
         level = this.Get("scriptlevel");
       } else if (String(level).match(/^ *[-+]/)) {
-        delete this.scriptlevel;
-        var LEVEL = this.Get("scriptlevel");
-        this.scriptlevel = level;
+        var LEVEL = this.Get("scriptlevel",null,true);
         level = LEVEL + parseInt(level);
       }
       return level;
@@ -916,6 +934,7 @@ MathJax.ElementJax.mml.Augment({
       mpadded: {width: true, height: true, depth: true, lspace: true, voffset: true},
       mtable:  {width: true, height: true, depth: true, align: true}
     },
+    getRemoved: {fontfamily:"fontFamily", fontweight:"fontWeight", fontstyle:"fontStyle", fontsize:"fontSize"},
     setTeXclass: MML.mbase.setChildTeXclass
   });
 
@@ -980,7 +999,7 @@ MathJax.ElementJax.mml.Augment({
         //
         //  Clear flag for using MML spacing even though form is specified
         //
-        this.data.open.useMMLspacing &= ~this.data.open.SPACE_ATTR.form;
+        this.data.open.useMMLspacing = 0;
       }
       //
       //  Create fake nodes for the separators
@@ -989,8 +1008,10 @@ MathJax.ElementJax.mml.Augment({
         while (values.separators.length < this.data.length)
           {values.separators += values.separators.charAt(values.separators.length-1)}
         for (var i = 1, m = this.data.length; i < m; i++) {
-          if (this.data[i])
-            {this.SetData("sep"+i,MML.mo(values.separators.charAt(i-1)).With({separator:true}))}
+          if (this.data[i]) {
+            this.SetData("sep"+i,MML.mo(values.separators.charAt(i-1)).With({separator:true}))
+            this.data["sep"+i].useMMLspacing = 0;
+          }
         }
       }
       //
@@ -1003,7 +1024,7 @@ MathJax.ElementJax.mml.Augment({
         //
         //  Clear flag for using MML spacing even though form is specified
         //
-        this.data.close.useMMLspacing &= ~this.data.close.SPACE_ATTR.form;
+        this.data.close.useMMLspacing = 0;
       }
     },
     texClass: MML.TEXCLASS.OPEN,
@@ -1177,7 +1198,7 @@ MathJax.ElementJax.mml.Augment({
     Append: function () {
       for (var i = 0, m = arguments.length; i < m; i++) {
         if (!((arguments[i] instanceof MML.mtr) ||
-              (arguments[i] instanceof MML.mlabeledtr))) {arguments[i] = MML.mtd(arguments[i])}
+              (arguments[i] instanceof MML.mlabeledtr))) {arguments[i] = MML.mtr(arguments[i])}
       }
       this.SUPER(arguments).Append.apply(this,arguments);
     },
@@ -1228,7 +1249,7 @@ MathJax.ElementJax.mml.Augment({
   });
 
   MML.maligngroup = MML.mbase.Subclass({
-    type: "malign",
+    type: "maligngroup",
     isSpacelike: function () {return true},
     defaults: {
       mathbackground: MML.INHERIT,
@@ -1274,7 +1295,10 @@ MathJax.ElementJax.mml.Augment({
         // Make sure tooltip has proper spacing when typeset (see issue #412)
         this.data[1].setTeXclass();
       }
-      return this.selected().setTeXclass(prev);
+      var selected = this.selected();
+      prev = selected.setTeXclass(prev);
+      this.updateTeXclass(selected);
+      return prev;
     }
   });
   
